ml4co_kit.data
=======================

.. currentmodule:: ml4co_kit.data

.. autosummary::
   :toctree: _autosummary
   :recursive:

   ml4co_kit.data.cvrp.cvrp_uniform
   ml4co_kit.data.cvrp.vrplib_original
   ml4co_kit.data.mis.satlib_original
   ml4co_kit.data.tsp.ml4tsp
   ml4co_kit.data.tsp.tsp_uniform
   ml4co_kit.data.tsp.tsplib_original
   ml4co_kit.data.tsp.tsplib4ml
